package com.ruoyi.ibs.list.mapper;

import java.util.List;

import com.ruoyi.ibs.list.domain.CustDeptUserCmpm;


/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author ruoyi
 * @date 2025-01-02
 */
public interface CustDeptUserCmpmMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public CustDeptUserCmpm selectCustDeptUserCmpmById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param custDeptUserCmpm 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<CustDeptUserCmpm> selectCustDeptUserCmpmList(CustDeptUserCmpm custDeptUserCmpm);

    /**
     * 新增【请填写功能名称】
     * 
     * @param custDeptUserCmpm 【请填写功能名称】
     * @return 结果
     */
    public int insertCustDeptUserCmpm(CustDeptUserCmpm custDeptUserCmpm);

    /**
     * 修改【请填写功能名称】
     * 
     * @param custDeptUserCmpm 【请填写功能名称】
     * @return 结果
     */
    public int updateCustDeptUserCmpm(CustDeptUserCmpm custDeptUserCmpm);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteCustDeptUserCmpmById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCustDeptUserCmpmByIds(Long[] ids);
}
