package com.ruoyi.ibs.list.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.ibs.list.domain.CustDeptUserCmpm;
import com.ruoyi.ibs.list.service.ICustDeptUserCmpmService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2025-01-02
 */
@RestController
@RequestMapping("/system/cmpm")
public class CustDeptUserCmpmController extends BaseController
{
    @Autowired
    private ICustDeptUserCmpmService custDeptUserCmpmService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:cmpm:list')")
    @GetMapping("/list")
    public TableDataInfo list(CustDeptUserCmpm custDeptUserCmpm)
    {
        startPage();
        List<CustDeptUserCmpm> list = custDeptUserCmpmService.selectCustDeptUserCmpmList(custDeptUserCmpm);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:cmpm:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, CustDeptUserCmpm custDeptUserCmpm)
    {
        List<CustDeptUserCmpm> list = custDeptUserCmpmService.selectCustDeptUserCmpmList(custDeptUserCmpm);
        ExcelUtil<CustDeptUserCmpm> util = new ExcelUtil<CustDeptUserCmpm>(CustDeptUserCmpm.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:cmpm:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(custDeptUserCmpmService.selectCustDeptUserCmpmById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:cmpm:add')")
    @PostMapping
    public AjaxResult add(@RequestBody CustDeptUserCmpm custDeptUserCmpm)
    {
        return toAjax(custDeptUserCmpmService.insertCustDeptUserCmpm(custDeptUserCmpm));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:cmpm:edit')")
    @PutMapping
    public AjaxResult edit(@RequestBody CustDeptUserCmpm custDeptUserCmpm)
    {
        return toAjax(custDeptUserCmpmService.updateCustDeptUserCmpm(custDeptUserCmpm));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:cmpm:remove')")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(custDeptUserCmpmService.deleteCustDeptUserCmpmByIds(ids));
    }
}
